@@ -232,6 +232,11 @@ bool LibPython::loadSymbols(bool python3, std::string* pError)
   LOAD_PYTHON_SYMBOL(PyObject_CallFunctionObjArgs)
   LOAD_PYTHON_SYMBOL(PyType_IsSubtype)
   LOAD_PYTHON_SYMBOL(PySys_WriteStderr)
+  LOAD_PYTHON_SYMBOL(PyEval_SetProfile)
+  LOAD_PYTHON_SYMBOL(PyGILState_GetThisThreadState)
+  LOAD_PYTHON_SYMBOL(PyGILState_Ensure)
+  LOAD_PYTHON_SYMBOL(PyGILState_Release)
+  LOAD_PYTHON_SYMBOL(PyThreadState_Next)
 
   // PyUnicode_AsEncodedString may have several different names depending on the Python
   // version and the UCS build type 
